ai
ai
QRT’s curated generative-AI workbench.
Classes
| Name | Description |
|---|---|
| Agent | A typed bounded agent delegated to Pydantic AI. |
| Client | Immutable configuration boundary for QRT AI operations. |
| ModelDeployment | A stable logical alias for a deployed model. |
| ModelRef | A provider-qualified model identity. |
Agent
ai.Agent(model, tools, output, limits=None, instructions=None)A typed bounded agent delegated to Pydantic AI.
Client
ai.Client(
providers=None,
deployments=None,
retry=None,
media=None,
redaction=None,
tracker=None,
strict_capabilities=False,
_backends=None,
)Immutable configuration boundary for QRT AI operations.
ModelDeployment
ai.ModelDeployment()A stable logical alias for a deployed model.
ModelRef
ai.ModelRef()A provider-qualified model identity.
Functions
| Name | Description |
|---|---|
| agenerate | Asynchronously generate a normalized result using the default client. |
| default_client | Return the lazily constructed environment-derived client. |
| embed | Embed inputs using a configured provider on the default client. |
| extract | Generate and validate a Pydantic object using the default client. |
| generate | Generate a normalized result using the default client. |
| tool | Decorate a callable as a typed QRT tool. |
agenerate
ai.agenerate(**kwargs)Asynchronously generate a normalized result using the default client.
default_client
ai.default_client()Return the lazily constructed environment-derived client.
embed
ai.embed(inputs, *, model, **kwargs)Embed inputs using a configured provider on the default client.
extract
ai.extract(**kwargs)Generate and validate a Pydantic object using the default client.
generate
ai.generate(**kwargs)Generate a normalized result using the default client.
tool
ai.tool(name, input, output, description='', timeout=30.0)Decorate a callable as a typed QRT tool.